@@ -1,5 +1,5 @@
 /* $XFree86$ */
-/* $XdotOrg$ */
+/* $XdotOrg: driver/xf86-video-sis/src/sis.h,v 1.67 2006/04/07 21:05:21 ajax Exp $ */
 /*
  * Main global data and definitions
  *
@@ -35,6 +35,11 @@
 #ifndef _SIS_H_
 #define _SIS_H_
 
+#include <stdio.h>
+#include <string.h>
+#include <math.h>
+#include <setjmp.h>
+
 #define SISDRIVERVERSIONYEAR    5
 #define SISDRIVERVERSIONMONTH   9
 #define SISDRIVERVERSIONDAY     20
@@ -65,7 +70,6 @@
 #include "siscp.H"
 #endif
 
-#include "xf86_ansic.h"
 #include "compiler.h"
 #include "xf86Pci.h"
 #include "xf86Priv.h"
@@ -88,7 +92,7 @@
 	(((major) * 10000000) + ((minor) * 100000) + ((patch) * 1000) + snap)
 #define XF86_VERSION_CURRENT XF86_VERSION_NUMERIC(4,3,99,902,0)
 #endif
-#if XORG_VERSION_CURRENT >= XORG_VERSION_NUMERIC(6,8,99,900,0)
+#if XORG_VERSION_CURRENT >= XORG_VERSION_NUMERIC(6,8,99,900,0) || XORG_VERSION_CURRENT < XORG_VERSION_NUMERIC(4,0,0,0,0)
 #define SISISXORG6899900
 #endif
 #if 0
@@ -105,13 +109,14 @@
 
 #define SIS_NAME                "SIS"
 #define SIS_DRIVER_NAME         "sis"
-#define SIS_MAJOR_VERSION       0
+#define SIS_MAJOR_VERSION	PACKAGE_VERSION_MAJOR
 #ifdef SISISXORG6899900
-#define SIS_MINOR_VERSION       8	/* DRI changes */
+#define SIS_MINOR_VERSION	PACKAGE_VERSION_MINOR	/* DRI changes */
+#define SIS_PATCHLEVEL		PACKAGE_VERSION_PATCHLEVEL
 #else
 #define SIS_MINOR_VERSION       7
-#endif
 #define SIS_PATCHLEVEL          1
+#endif
 #define SIS_CURRENT_VERSION     ((SIS_MAJOR_VERSION << 16) | \
                                  (SIS_MINOR_VERSION << 8) | SIS_PATCHLEVEL )
 
